<?php
/*                                                                                                                                                       
  mememe                                     ememem
    \ememememem                       ememememem/ 
     ememememememem               ememememememem  
      emememememememe           emememememememe   
         \memememememem       ememememememe/      
         emememememememe     emememememememe     
                 emememem   ememememe              
                     ememe ememe                   
                       emememe                     
                         eme
                          e 

	^^ Title : ProvenExpert							 
	^^ Create : 2021-07-12
    ^^ For PS version 1.6, 1.7
	^^ Copyright : EAGLEMEDIA.de
*/

if (!defined('_PS_VERSION_')) 
	exit;

require(__DIR__ . '/provenexpert_api.php');
	
class ProvenExpert extends Module
{
    
	public function __construct()
	{
		$this->name = 'provenexpert';
		$this->tab = 'front_office_features';
		$this->version = '1.6.2';
		$this->author = 'EAGLEMEDIA.de';

        $this->bootstrap = true; // styles
		parent::__construct();

		$this->displayName = $this->l('ProvenExpert - rating seals');
		$this->description = $this->l('Display the ProvenExpert rating seals in your online shop with the Google star ratings block. Supported up to ProvenExpert package PLUS');
        $this->ps_versions_compliancy = array('min' => '1.6.0.0', 'max' => '1.7.99.99');
        $this->confirmUninstall = $this->l('Are you sure you want to delete this module?');        
	}

	public function install()
	{
		if( parent::install() &&
			$this->registerHook('header') &&
			$this->registerHook('footer') ) {
            
            $res  = Configuration::updateValue('PROVENEXPERT_API_URL', 'https://www.provenexpert.com/api_rating_v2.json' );
            $res &= Configuration::updateValue('PROVENEXPERT_API_DEBUG', 0);
            $res &= $this->installFixtures();
			$res &= $this->createTable();
            $res &= function_exists('curl_init');            
            $res &= ProvenExpertApi::setApiCachePath();

			return (bool)$res;
		}

		return false;
	}
    
	protected function installFixtures()
	{
        $res = true; 
		$languages = Language::getLanguages(false);
		foreach ($languages as $lang) 
        {  
            $values['PROVENEXPERT_API_USER'][(int)$lang['id_lang']] = '';		
            $values['PROVENEXPERT_API_KEY'][(int)$lang['id_lang']] = '';             
            
			$res &= Configuration::updateValue('PROVENEXPERT_API_USER', $values['PROVENEXPERT_API_USER'] );
			$res &= Configuration::updateValue('PROVENEXPERT_API_KEY', $values['PROVENEXPERT_API_KEY'] );             
        }

		return (bool)$res;
	}
	
	public function uninstall()
	{
		$this->_clearCache('*');
				
		if (parent::uninstall())
		{
			$res  = $this->deleteTable();
            $res &= Configuration::deleteByName('PROVENEXPERT_API_URL');
            $res &= Configuration::deleteByName('PROVENEXPERT_API_DEBUG');
			$res &= Configuration::deleteByName('PROVENEXPERT_API_USER');
			$res &= Configuration::deleteByName('PROVENEXPERT_API_KEY');			
			return (bool)$res;
		}
        
		return false;
	}
    
	protected function createTable()
	{
		/* Seals lang configuration */
		return Db::getInstance()->execute('
			CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'provenexpert_rating_seals` (
			  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,			  
              `id_lang` int(10) unsigned NOT NULL,
              `rating_seals` text NOT NULL,
			  PRIMARY KEY (`id`)
			) ENGINE='._MYSQL_ENGINE_.' DEFAULT CHARSET=UTF8
		');		
	}

	protected function deleteTable()
	{
		return Db::getInstance()->execute('
			DROP TABLE IF EXISTS `'._DB_PREFIX_.'provenexpert_rating_seals`
		');
	}

	protected function updateTable($id_lang, $html = false)
	{    
        $res ='';
        $html_seales = trim(utf8_encode(Tools::getValue('PROVENEXPERT_RATING_SEALS_'.$id_lang)));

        $res = Db::getInstance(_PS_USE_SQL_SLAVE_)->getRow('
            SELECT * 
            FROM `'._DB_PREFIX_.'provenexpert_rating_seals`
            WHERE `id_lang` = '.(int)$id_lang
        );
       
        if (!$res['id']) {
            $res = Db::getInstance()->execute('
                INSERT INTO '._DB_PREFIX_.'provenexpert_rating_seals (`id_lang`,`rating_seals`) 
                VALUES ("'.(int)$id_lang.'", "'.pSQL($html_seales, $html).'")
            ');
        } else {            
             $res = Db::getInstance()->execute('
                UPDATE `'._DB_PREFIX_.'provenexpert_rating_seals` 
                SET `rating_seals` = \''.pSQL($html_seales, $html).'\'
                WHERE `id_lang` = '.(int)$id_lang
            );            
        }
        
        return (bool)$res;
    }
  
	public function getRatingSeal($id_lang)
	{       
		$res = Db::getInstance(_PS_USE_SQL_SLAVE_)->getRow('
            SELECT *
            FROM `'._DB_PREFIX_.'provenexpert_rating_seals`
            WHERE `id_lang` = '.(int)$id_lang
        );
        
        return $res['rating_seals']; 
	}
    
    
    
    
	public function postProcess()
	{
		$errors ='';            
            
		if ( Tools::isSubmit('SubmitProvenExpert') )
        {
            Configuration::updateValue('PROVENEXPERT_API_DEBUG', Tools::getValue('PROVENEXPERT_API_DEBUG'));
            Configuration::updateValue('PROVENEXPERT_API_URL', Tools::getValue('PROVENEXPERT_API_URL'));        
            /* Cache directory must be empty when change the api url */
            if (file_exists(__DIR__.ProvenExpertApi::$cachePath)) {
                unlink(__DIR__.ProvenExpertApi::$cachePath); 
                unlink(__DIR__.ProvenExpertApi::$errorFile);
                rmdir(__DIR__.ProvenExpertApi::$cacheDirectory);                
                ProvenExpertApi::setApiCachePath();
            }
            
            
            $languages = Language::getLanguages(false);
            foreach ($languages as $lang)
            {               
                if (!Tools::getValue('PROVENEXPERT_API_USER_'.$lang['id_lang']))
                    $errors .= $this->displayError($this->l('The Api user can not be empty') . ' - ' . strtoupper($lang['iso_code']));
                    else {
                        $value['PROVENEXPERT_API_USER'][(int)$lang['id_lang']] = Tools::getValue('PROVENEXPERT_API_USER_'.$lang['id_lang']);
                        Configuration::updateValue('PROVENEXPERT_API_USER', $value['PROVENEXPERT_API_USER']);      
                    }
                
                if (!Tools::getValue('PROVENEXPERT_API_KEY_'.$lang['id_lang']))
                    $errors .= $this->displayError($this->l('The Api key can not be empty') . ' - ' . strtoupper($lang['iso_code']));
                    else {
                        $value['PROVENEXPERT_API_KEY'][(int)$lang['id_lang']] = Tools::getValue('PROVENEXPERT_API_KEY_'.$lang['id_lang']);
                        Configuration::updateValue('PROVENEXPERT_API_KEY', $value['PROVENEXPERT_API_KEY']);
                    } 
                
                if (!Tools::getValue('PROVENEXPERT_RATING_SEALS_'.$lang['id_lang']))
                    $errors .= $this->displayError($this->l('The Api seals can not be empty') . ' - ' . strtoupper($lang['iso_code']));
                    else
                        $this->updateTable($lang['id_lang'], true);
            } 
            
            if (!$errors)
                return $this->displayConfirmation($this->l('The settings have been updated.'));          
            
            return $errors;
        }            
	}            
            
	public function getContent()
	{		
		return $this->postProcess().$this->renderForm();
	}
    
	public function renderForm()
	{
        
	    $fields_form_1 = '
            <div class="loginpageslide text-center">
                '.$this->l('Have a look at my modules for PrestaShop').' -
                <a href="https://eaglemedia.de/cms.php?s=prestashop-module" target="_blank"><b>MODULE</b></a>
                <p class="clear"> </p>
                '.$this->l('Made with').' <i class="icon-heart"></i> '.$this->l('by').'
                <a href="http://eaglemedia.de" target="_blank"><b>EAGLEMEDIA</b></a>
                <p class="clear"><br/> </p>

                <form action="https://www.paypal.com/donate" method="post" target="_blank">
                    <input type="hidden" name="hosted_button_id" value="ALLRFT5RZJVHN" />
                    <input type="image" src="https://www.paypalobjects.com/de_DE/DE/i/btn/btn_donateCC_LG.gif" 
                           border="0" name="submit" title="PayPal - The safer, easier way to pay online!" alt="Donate with PayPal button" />

                    <img alt="" border="0" src="https://www.paypal.com/de_DE/i/scr/pixel.gif" width="1" height="1" />
                </form>
                <p class="clear"><br/><br/> </p>	
            </div>';
        
        $fields_form_2 = '
            <div class="panel">
                <div class="panel-heading">
				    <i class="icon-cogs"></i> '.$this->l('Examples').'
				</div>
                <div class="text-center">
                    <img src="'.Tools::getHttpHost(true).__PS_BASE_URI__.'modules/provenexpert/views/img/virtual_mode.png" alt="virtual mode" style="max-width:100%" />
                    <img src="'.Tools::getHttpHost(true).__PS_BASE_URI__.'modules/provenexpert/views/img/virtual_mode_stars.png" alt="virtual mode stars" style="max-width:100%" />
                </div>
                <p class="clear"><br/> </p>	
            </div>';
        
        $fields_form_3 = '        
            <div class="alert alert-warning">'.$this->l('SEO: When proSeal selected, then replace in seal code "hideData: false" to "hideData: true" for prevent of additionalen product microdatas.').'</div>
            <div class="alert alert-warning">'.$this->l('UPDATE: Make sure that every time you regenerate the seal code, you enter it here and update it!').'</div>';            

		$fields_form_4 = array(
			'form' => array(
				'legend' => array(
					'title' => $this->l('Settings'),
					'icon' => 'icon-cogs'
				),
				'input' => array(                    
					array(
						'type' => 'text',				
						'label' => $this->l('Api user'),
						'name' => 'PROVENEXPERT_API_USER',
						'class' => 'provenexpert',
						'desc' => $this->l(''),
                        'lang' => true
					),
					array(
						'type' => 'text',				
						'label' => $this->l('Api key'),
						'name' => 'PROVENEXPERT_API_KEY',
						'class' => 'provenexpert',
						'desc' => $this->l('Go to website.. https://app.provenexpert.com. Then to menu item \'Administration -> Developer API\' and copy the details and paste it here.'),
                        'lang' => true
					),
                    array(                        
                        'label' => $this->l('Visual rating block'),
                        'name' => 'PROVENEXPERT_API_URL',
                        'type' => 'select',
                        'options' => array(
                            'query' => array(
                                array('id' => 'https://www.provenexpert.com/api_rating_v2.json', 'name' => $this->l('Visual mode 1')),
                                array('id' => 'https://www.provenexpert.com/api_rating_v3.json', 'name' => $this->l('Visual mode 2')),
                                array('id' => 'https://www.provenexpert.com/api_rating_v4.json', 'name' => $this->l('Visual mode 3')),
                                array('id' => 'https://www.provenexpert.com/api_rating_v5.json', 'name' => $this->l('Visual mode 4')),                            
                            ),
                            'id' => 'id',
                            'name' => 'name'
                        ),
                        'class' => 'fixed-width-xxl',
                        'desc' => $this->l('See top images.')
                    ),
					array( 
						'type' => 'switch',
						'label' => $this->l('Api debug mode'),
						'name' => 'PROVENEXPERT_API_DEBUG',
						'class' => 'fixed-width-xs',						
						'values' => array(
							array(
								'id' => 'active_on',
								'value' => 1,
								'label' => $this->l('Yes')
							),
							array(
								'id' => 'active_off',
								'value' => 0,
								'label' => $this->l('No')
							)
						),
                        'desc' => $this->l('Debug notes are displayed in front.'),
					),
					array(
						'type' => 'textarea',				
						'label' => $this->l('Virtual seals'),
						'name' => 'PROVENEXPERT_RATING_SEALS',
						'class' => 'provenexpert',
						'desc' => $this->l('Go to website.. https://app.provenexpert.com. Then to menu item \'Reputation Boost\' and copy the seal and paste it here.'),
                        'lang' => true
					),

				),   
				'submit' => array(
					'title' => $this->l('Update')
				)
			)
		);

		$helper = new HelperForm();
		$helper->show_toolbar = false;
		$helper->table =  $this->table;
		$lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
		$helper->default_form_language = $lang->id;
		$helper->module = $this;
		$helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
		$helper->identifier = $this->identifier;
		$helper->submit_action = 'SubmitProvenExpert';
		$helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
		$helper->token = Tools::getAdminTokenLite('AdminModules');
		$helper->tpl_vars = array(
			'uri' => $this->getPathUri(),
			'fields_value' => $this->getConfigFieldsValues(),
			'languages' => $this->context->controller->getLanguages(),
			'id_language' => $this->context->language->id
		);

		return $fields_form_2.$helper->generateForm(array($fields_form_4)).$fields_form_3.$fields_form_1;
	}	

	public function getConfigFieldsValues()
	{        
        $languages = Language::getLanguages(false);
		foreach ($languages as $lang)
		{		
			$fields['PROVENEXPERT_API_URL'] = Tools::getValue('PROVENEXPERT_API_URL', Configuration::get('PROVENEXPERT_API_URL'));
            $fields['PROVENEXPERT_API_DEBUG'] = Tools::getValue('PROVENEXPERT_API_DEBUG', Configuration::get('PROVENEXPERT_API_DEBUG'));
			$fields['PROVENEXPERT_API_USER'][$lang['id_lang']] = Tools::getValue('PROVENEXPERT_API_USER_'.$lang['id_lang'], Configuration::get('PROVENEXPERT_API_USER', $lang['id_lang']));
			$fields['PROVENEXPERT_API_KEY'][$lang['id_lang']] = Tools::getValue('PROVENEXPERT_API_KEY_'.$lang['id_lang'], Configuration::get('PROVENEXPERT_API_KEY', $lang['id_lang']));
			$fields['PROVENEXPERT_RATING_SEALS'][$lang['id_lang']] = Tools::getValue('PROVENEXPERT_RATING_SEALS_'.$lang['id_lang'], $this->getRatingSeal($lang['id_lang']));
		}

		return $fields;
	}

    public function hookHeader()
	{  		
        $this->context->controller->addCSS($this->_path.'views/css/provenexpert.css', 'all');	
        $this->context->controller->addCSS($this->_path.'views/css/provenexpert_api.css', 'all');
	}
            
	public function hookFooter( $params )
	{
        $id_lang = $this->context->language->id;
        $apiURL = Configuration::get('PROVENEXPERT_API_URL');
        $apiUSER = Configuration::get('PROVENEXPERT_API_USER', $id_lang);
        $apiKEY = Configuration::get('PROVENEXPERT_API_KEY', $id_lang);

		$this->context->smarty->assign(
		    array(
                'rating_seal_dummy' => $this->_path.'views/img/provenexpert.jpg',
                'rating_seal' => $this->getRatingSeal($this->context->language->id),
                'rating_details' => ProvenExpertApi::getApiRequestDetails($apiURL, $apiUSER, $apiKEY),
                'rating_debug' => Configuration::get('PROVENEXPERT_API_DEBUG'),
                'ps_version' => (version_compare(_PS_VERSION_, '1.7.0', '>=') ? '17' : '16')
		    )		    
		);

		return $this->display(__FILE__, 'views/provenexpert.tpl');
	}
            
}
